@@ -299,9 +299,109 @@ class WRiderCommand(Command):
 
     def __init__(self):
         super(WRiderCommand, self).__init__()
+        self.wrider_container_name = u'wrider_webserver_container'
+        self.client = docker_client()
+
+    def get_prog(self):
+        return "%s %s" % (get_prog(), self.name)
 
     def run(self, args):
-        client = docker_client()
+        #sub command class
+        class WRiderStartCommand(self.__class__):
+            name = "wrider start"
+            subcommand = "start"
+            usage = """%prog"""
+            summary = "start wrider container"
+
+            def __init__(self):
+                super(WRiderStartCommand, self).__init__()
+
+            def run(self, args):
+
+                if self.is_wrider_container_exist():
+                    if self.is_wrider_container_up():
+                        h_port = self.get_wrider_container_port()
+                        msg = '\nWRider web link is: http://boot2docker:{p}\n'.format(p=h_port)
+                        sys.stdout.write(msg)
+                        sys.stdout.write('\n')
+                    else:
+                        self.remove_wrider_container()
+                        self.create_wrider_container()
+                else:
+                    # Create container with the name
+                    self.create_wrider_container()
+
+        class WRiderStopCommand(self.__class__):
+            name = "wrider stop"
+            subcommand = "stop"
+            usage = """%prog"""
+            summary = "stop wrider container"
+
+            def __init__(self):
+                super(WRiderStopCommand, self).__init__()
+
+            def run(self, args):
+                if self.is_wrider_container_exist():
+                    self.stop_wrider_container()
+
+        sub_commands = {
+            WRiderStartCommand.subcommand: WRiderStartCommand,
+            WRiderStopCommand.subcommand: WRiderStopCommand
+        }
+
+        parser_kw = {
+            'usage': '\n%prog <command> [options]',
+            'add_help_option': False,
+            'formatter': UpdatingDefaultsHelpFormatter(),
+            'name': 'global',
+            'prog': self.get_prog(),
+        }
+        sub_command, args_else = parse_opts(args, get_commands_summary(sub_commands), parser_kw,
+                                            cmdoptions.general_group)
+
+        sub_commands[sub_command]().run(args_else)
+
+    def is_wrider_container_exist(self):
+        containers = self.client.containers(all=True)
+        for container in containers:
+            name = self.get_container_name(container)
+            if name == self.wrider_container_name:
+                return True
+        return False
+
+    def is_wrider_container_up(self):
+        containers = self.client.containers(all=True)
+        for container in containers:
+            name = self.get_container_name(container)
+            if name == self.wrider_container_name:
+                if 'Up' in str(container['Status']):
+                    return True
+        return False
+
+    def get_container_name(self, container):
+        if container:
+            name_list = container['Names']
+            return name_list[0][1:]
+        return None
+
+    def stop_wrider_container(self):
+        containers = self.client.containers(all=True)
+        for container in containers:
+            if self.get_container_name(container) == self.wrider_container_name:
+                sys.stdout.write('Stopping...')
+                self.client.stop(container["Id"])
+
+        msg = '\nWRider container was stopped successfully.\n\n'
+        sys.stdout.write(msg)
+
+    def remove_wrider_container(self):
+        containers = self.client.containers(all=True)
+        for container in containers:
+            if self.get_container_name(container) == self.wrider_container_name:
+                self.client.remove_container(container["Id"])
+
+    def create_wrider_container(self):
+
         cert_path = os.environ.get('DOCKER_CERT_PATH', '')
         docker_host = "tcp://boot2docker:2376"
         docker_cert_path = "/code/boot2docker-vm"
@@ -310,19 +410,30 @@ class WRiderCommand(Command):
                        'DOCKER_CERT_PATH='+docker_cert_path,
                        'DOCKER_HOST='+docker_host]
 
-        container_id = client.create_container(
-            image=image_name, environment=environment)
+        container_id = self.client.create_container(
+            image=image_name, environment=environment, name=self.wrider_container_name)
 
-        client.start(container=container_id, publish_all_ports=True,
+        sys.stdout.write('Starting...\n')
+        self.client.start(container=container_id, publish_all_ports=True,
                      binds={cert_path: {'bind': docker_cert_path, 'ro': False}})
-        h_port = client.port(container_id, 5000)
+
         docker_host_ip = self.get_docker_host_ip()
         msg = '\n\
-        You need to do below two steps to use your Wrider container ready:\n \
+        WRider containder started successfully\n \
+        You need to do below two steps to use your WRider container ready:\n \
         1. sudo echo "{i}   boot2docker" >> /etc/hosts\n \
         2. Open your browser and access http://boot2docker:{p}\n \
-        '.format(i=docker_host_ip, p=h_port[0].get('HostPort'))
+        '.format(i=docker_host_ip, p=self.get_wrider_container_port())
         sys.stdout.write(msg)
+        sys.stdout.write('\n')
+
+    def get_wrider_container_port(self):
+        containers = self.client.containers(all=True)
+        for container in containers:
+            if self.get_container_name(container) == self.wrider_container_name:
+                h_port = self.client.port(container["Id"], 5000)
+                return h_port[0].get('HostPort')
+
 
     def get_docker_host_ip(self):
         '''
